summaryrefslogtreecommitdiffstats
path: root/test/tmisc.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/tmisc.c')
-rw-r--r--test/tmisc.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/test/tmisc.c b/test/tmisc.c
index 2a977bf..02521e4 100644
--- a/test/tmisc.c
+++ b/test/tmisc.c
@@ -3481,15 +3481,15 @@ test_misc19(void)
HDfree(vfd_cls);
-/* Check H5I operations on virtual object drivers */
+/* Check H5I operations on virtual object plugins */
/* Get a VOL class to register */
vol_cls = h5_get_dummy_vol_class();
CHECK(vol_cls, NULL, "h5_get_dummy_vol_class");
- /* Register a VOL driver */
- volid = H5VLregister_driver(vol_cls);
- CHECK(volid, FAIL, "H5VLregister_driver");
+ /* Register a VOL plugin */
+ volid = H5VLregister_plugin(vol_cls, H5P_DEFAULT);
+ CHECK(volid, FAIL, "H5VLregister_plugin");
/* Check the reference count */
rc = H5Iget_ref(volid);
@@ -3499,23 +3499,23 @@ test_misc19(void)
rc = H5Iinc_ref(volid);
VERIFY(rc, 2, "H5Iinc_ref");
- /* Unregister the VOL driver normally */
- ret = H5VLunregister_driver(volid);
- CHECK(ret, FAIL, "H5VLunregister_driver");
+ /* Unregister the VOL plugin normally */
+ ret = H5VLunregister_plugin(volid);
+ CHECK(ret, FAIL, "H5VLunregister_plugin");
/* Check the reference count */
rc = H5Iget_ref(volid);
VERIFY(rc, 1, "H5Iget_ref");
/* Unregister the VOL driver by decrementing the reference count */
rc = H5Idec_ref(volid);
VERIFY(rc, 0, "H5Idec_ref");
/* Try unregistering the VOL driver again (should fail) */
H5E_BEGIN_TRY {
- ret = H5VLunregister_driver(volid);
+ ret = H5VLunregister_plugin(volid);
} H5E_END_TRY;
- VERIFY(ret, FAIL, "H5VLunregister_driver");
+ VERIFY(ret, FAIL, "H5VLunregister_plugin");
HDfree(vol_cls);
@@ -3499,23 +3499,23 @@ test_misc19(void)
rc = H5Iget_ref(volid);
VERIFY(rc, 1, "H5Iget_ref");
- /* Unregister the VOL driver by decrementing the reference count */
+ /* Unregister the VOL plugin by decrementing the reference count */
rc = H5Idec_ref(volid);
VERIFY(rc, 0, "H5Idec_ref");
@@ -3499,23 +3499,23 @@ test_misc19(void)
rc = H5Idec_ref(volid);
VERIFY(rc, 0, "H5Idec_ref");
- /* Try unregistering the VOL driver again (should fail) */
+ /* Try unregistering the VOL plugin again (should fail) */
H5E_BEGIN_TRY {